Enum ra_ap_ide::AssistResolveStrategy
source · pub enum AssistResolveStrategy {
None,
All,
Single(SingleResolve),
}Expand description
A way to control how many assist to resolve during the assist resolution. When an assist is resolved, its edits are calculated that might be costly to always do by default.
Variants
None
No assists should be resolved.
All
All assists should be resolved.
Single(SingleResolve)
Only a certain assist should be resolved.
Implementations
sourceimpl AssistResolveStrategy
impl AssistResolveStrategy
pub fn should_resolve(&self, id: &AssistId) -> bool